@@ -1,5 +1,5 @@
 cond.cdf=function(p.eval,ncp,test=c("t","z"),alternative=c("two.sided","less","greater"),
-    df=if(test=="z")Inf else df,keep.cdf=TRUE,suppressWarnings=TRUE) #,save=FALSE)
+    df=if(test=="z")Inf else df,keep.cdf=NULL,suppressWarnings=TRUE) #,save=FALSE)
 {
 # conditional cdf of the p-value evaluated at p.eval, given ncp. 
 # The output dim is c( length(p.eval), length(ncp) )
@@ -16,15 +16,27 @@ cond.cdf=function(p.eval,ncp,test=c("t","z"),alternative=c("two.sided","less","g
     cdfp.prefix=paste("Npeval_",Npeval,"__MAXncp",MAXncp,"__Nncp_",Nncp,"__test_",test,
                      "__alternative_",alternative,"__df_",df, sep='')
 
-    exist.hiddenEnv=exists(".pi0cdfp", envir=globalenv())
-    if(exist.hiddenEnv) {	
+    #exist.hiddenEnv=exists(".pi0cdfp", envir=globalenv())
+	if(is.logical(keep.cdf)){
+		if(isTRUE(keep.cdf)){
+			warning("As of version 1.4-0, 'keep.cdf=TRUE' is no longer supported to comply with new CRAN policies. Please supply an environment")
+		}
+		keep.cdf= NULL
+	}
+	if(!is.null(keep.cdf) && !is.environment(keep.cdf)){
+		stop('"keep.cdf" needs to be an environment when it is non-null')
+	}
+    #if(exist.hiddenEnv) {	
+    if(!is.null(keep.cdf)  ) {	
         ## .pi0cdfp is a hidden environment in the global environment. 
         ## objects in this environment should be conditional cdf of p-values 
         ## given a vector of non-centrality parameters (ncp) 
         ## this section of code check if the desired result was already 
         ## kept in the environment or not
 
-        hiddenEnv=get('.pi0cdfp', envir=globalenv())
+
+        #hiddenEnv=get('.pi0cdfp', envir=globalenv())
+        hiddenEnv=keep.cdf
         existing.cdfps=grep(paste("^",cdfp.prefix,sep=''),ls(envir=hiddenEnv),value=TRUE)
         if(length(existing.cdfps)>0){
             check.attr=function(x) {
@@ -69,6 +81,7 @@ cond.cdf=function(p.eval,ncp,test=c("t","z"),alternative=c("two.sided","less","g
     if(isTRUE(suppressWarnings)){
         old.warning.level=options('warn')
         options(warn=-1)
+		on.exit(options(old.warning.level))
     }
     if(test=="z"){
         if(alternative=="greater"){
@@ -101,9 +114,9 @@ cond.cdf=function(p.eval,ncp,test=c("t","z"),alternative=c("two.sided","less","g
     }else{
             stop('test type not supported yet.')
     }
-    if(isTRUE(suppressWarnings)){
-        options(warn=old.warning.level$warn)
-    }
+#    if(isTRUE(suppressWarnings)){
+#        options(warn=old.warning.level$warn)
+#    }
 
     attr(p,"p.eval")=p.eval
     attr(p,"ncp")=ncp
@@ -111,16 +124,18 @@ cond.cdf=function(p.eval,ncp,test=c("t","z"),alternative=c("two.sided","less","g
     attr(p,"alternative")=alternative
     attr(p,"df")=df
 
-	if(keep.cdf){
-        if(!exist.hiddenEnv)
-            hiddenEnv=new.env()	
+	#if(keep.cdf){
+	if(!is.null(keep.cdf)) {
+        #if(!exist.hiddenEnv) hiddenEnv=new.env()	
+		hiddenEnv = keep.cdf
 
-        if(exist.hiddenEnv && length(existing.cdfps)>0){
+        #if(exist.hiddenEnv && length(existing.cdfps)>0){
+		if(length(existing.cdfps)>0){
             rslts=sapply(strsplit(existing.cdfps,"__"),tail,n=1)
             rslt.number=max(as.numeric(sapply(strsplit(rslts,"_"),tail,n=1)))+1
         }else rslt.number=1
         assign(paste(cdfp.prefix,"__rslt_",rslt.number,sep=''),p,envir=hiddenEnv)
-        if(!exist.hiddenEnv)assign(".pi0cdfp",hiddenEnv,envir=globalenv())
+        #if(!exist.hiddenEnv)assign(".pi0cdfp",hiddenEnv,envir=globalenv())
     }
                 
         
