@@ -14,9 +14,9 @@ plot.extrpi0=function(x,y,rgl=TRUE,...)
     if(rgl) rgl=requireNamespace("rgl",quitely=TRUE)
 
     if(rgl){
-        persp3d(nn1,nn2,plane,xlab='n1',ylab='n2',zlab='pi0',
+        rgl::persp3d(nn1,nn2,plane,xlab='n1',ylab='n2',zlab='pi0',
                 color='red',zlim=c(min(x[1],y),max(plane,y)),...)
-        plot3d(n1,n2,y,add=TRUE,col=4,size=3)
+        rgl::plot3d(n1,n2,y,add=TRUE,col=4,size=3)
     }else{
         warning("package rgl not found/used. Only static plot is generated")
         res=persp(nn1,nn2,plane,xlab='n1',ylab='n2',zlab='pi0',
