@@ -8,8 +8,7 @@ znormix=function(p, theoretical.null=TRUE, start.pi0, eps=1e-5, niter=Inf, verbo
     
     #starting values
     if(missing(start.pi0) || start.pi0<0 || start.pi0>1) {
-        #require(qvalue)
-        loadNamespace('qvalue')
+        requireNamespace('qvalue',quitely=TRUE)
         start.pi0=qvalue(p)$pi0
     }
     if(start.pi0<=0) start.pi0=1e-3
